@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+
 try:
     import urlparse
 except ImportError: #python 3
@@ -6,6 +7,7 @@ except ImportError: #python 3
 
 from webtest import TestResponse
 from django.test import Client
+from django.http import SimpleCookie
 
 class DjangoWebtestResponse(TestResponse):
     """
@@ -28,7 +30,9 @@ class DjangoWebtestResponse(TestResponse):
 
     @property
     def client(self):
-        return Client()
+        client = Client()
+        client.cookies = SimpleCookie(self.test_app.cookies)
+        return client
 
     def __getitem__(self, item):
         if item != 'Location':
